<?php
/**
 * Adventurous Customizer/Theme Options
 *
 * @package Catch Themes
 * @subpackage Adventurous
 * @since Adventurous 3.4
 */

/**
 * Implements Adventurous theme options into Theme Customizer.
 *
 * @param $wp_customize Theme Customizer object
 * @return void
 *
 * @since Adventurous 3.4
 */
function adventurous_customize_register( $wp_customize ) {
	$options  = adventurous_get_options();
	$defaults = adventurous_get_defaults();

	//Custom Controls
	require trailingslashit( get_template_directory() ) . 'inc/panel/customizer/customizer-custom-controls.php';

	$theme_slug = 'adventurous_';

	$settings_page_tabs = array(
		'theme_options' => array(
			'id' 			=> 'theme_options',
			'title' 		=> esc_html__( 'Theme Options', 'adventurous-pro' ),
			'description' 	=> esc_html__( 'Basic theme Options', 'adventurous-pro' ),
			'sections' 		=> array(
				'disable_responsive' => array(
					'id' => 'disable_responsive',
					'title' => esc_html__( 'Responsive Design', 'adventurous-pro' ),
					'description' => '',
				),
				'favicon' => array(
					'id' 			=> 'favicon',
					'title' 		=> esc_html__( 'Favicon', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'web_clip_icon_options' => array(
					'id' 			=> 'web_clip_icon_options',
					'title' 		=> esc_html__( 'Web Clip Icon Options', 'adventurous-pro' ),
					'description' 	=> esc_html__( 'Web Clip Icon for Apple devices. Recommended Size - Width 144px and Height 144px height, which will support High Resolution Devices like iPad Retina', 'adventurous-pro' )
				),
				'content_featured_image_options' => array(
					'id' 			=> 'content_featured_image_options',
					'title' 		=> esc_html__( 'Content Featured Image Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'promotion_headline_options' => array(
					'id' 			=> 'promotion_headline_options',
					'title' 		=> esc_html__( 'Promotion Headline Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'homepage_settings' => array(
					'id' 			=> 'homepage_settings',
					'title' 		=> esc_html__( 'Homepage/Frontpage Settings', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'layout_options' => array(
					'id' 			=> 'layout_options',
					'title' 		=> esc_html__( 'Layout Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'font_options' => array(
					'id' 			=> 'font_options',
					'title' 		=> esc_html__( 'Font Family Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'search_text_settings' => array(
					'id' 			=> 'search_text_settings',
					'title' 		=> esc_html__( 'Search Text Settings', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'excerpt_more_tag_settings' => array(
					'id' 			=> 'excerpt_more_tag_settings',
					'title' 		=> esc_html__( 'Excerpt / More Tag Settings', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'feed_url' => array(
					'id' 			=> 'feed_url',
					'title' 		=> esc_html__( 'Feed Url', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'commenting_setting' => array(
					'id' 			=> 'commenting_setting',
					'title' 		=> esc_html__( 'Comment Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'disable_scrollup' => array(
					'id' 			=> 'disable_scrollup',
					'title' 		=> esc_html__( 'Scroll Up', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'disable_notifier' => array(
					'id' 			=> 'disable_notifier',
					'title' 		=> esc_html__( 'Update Notifier', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'footer_option' => array(
					'id' 			=> 'footer_option',
					'title' 		=> esc_html__( 'Footer Editor Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'custom_css' => array(
					'id' 			=> 'custom_css',
					'title' 		=> esc_html__( 'Custom CSS', 'adventurous-pro' ),
					'description' 	=> '',
				),

			),
		),
		'featured_content' => array(
			'id' 			=> 'featured_content',
			'title' 		=> esc_html__( 'Featured Content', 'adventurous-pro' ),
			'description' 	=> esc_html__( 'Featured Content', 'adventurous-pro' ),
			'sections' 		=> array(
				'featured_content_settings' => array(
					'id' 			=> 'featured_content_settings',
					'title' 		=> esc_html__( 'Featured Content Settings', 'adventurous-pro' ),
					'description' 	=> '',
				),
			)
		),

		'featured_slider' => array(
			'id' 			=> 'featured_slider',
			'title' 		=> esc_html__( 'Featured Slider', 'adventurous-pro' ),
			'description' 	=> esc_html__( 'Featured Slider', 'adventurous-pro' ),
			'sections' 		=> array(
				'slider_options' => array(
					'id' 			=> 'slider_options',
					'title' 		=> esc_html__( 'Slider Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
			)
		),

		'social_links' => array(
			'id' 			=> 'social_links',
			'title' 		=> esc_html__( 'Social Links', 'adventurous-pro' ),
			'description' 	=> esc_html__( 'Add your social links here', 'adventurous-pro' ),
			'sections' 		=> array(
				'predefined_social_icons' => array(
					'id' 			=> 'predefined_social_icons',
					'title' 		=> esc_html__( 'Predefined Social Icons', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'custom_social_icons' => array(
					'id' 			=> 'custom_social_links',
					'title' 		=> esc_html__( 'Custom Social Links', 'adventurous-pro' ),
					'description' 	=> '',
				),
			),
		),

		'colors'	=> array(
			'id' 			=> 'colors',
			'title' 		=> esc_html__( 'Colors', 'adventurous-pro' ),
			'description' 	=> '',
			'priority'		=> '10',
			'sections' 		=> array(
				'basic_colors' => array(
					'id' 			=> 'basic_colors',
					'title' 		=> esc_html__( 'Basic Colors Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'header_right_menu_colors' => array(
					'id' 			=> 'header_right_menu_colors',
					'title' 		=> esc_html__( 'Primary Menu Color Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'header_secondary_menu_colors' => array(
					'id' 			=> 'header_secondary_menu_colors',
					'title' 		=> esc_html__( 'Header Secondary Menu Color Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'footer_menu_colors' => array(
					'id' 			=> 'footer_menu_colors',
					'title' 		=> esc_html__( 'Footer Menu Color Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'mobile_menu_colors' => array(
					'id' 			=> 'mobile_menu_colors',
					'title' 		=> esc_html__( 'Mobile Menu Color Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'reset_menu_color' => array(
					'id' 			=> 'reset_menu_color',
					'title' 		=> esc_html__( 'Reset Menu Color', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'site_colors' => array(
					'id' 			=> 'site_colors',
					'title' 		=> esc_html__( 'Site Color Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'promotion_colors' => array(
					'id' 			=> 'promotion_colors',
					'title' 		=> esc_html__( 'Promotion Color Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'sidebar_colors' => array(
					'id' 			=> 'sidebar_colors',
					'title' 		=> esc_html__( 'Sidebar Color Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'footer_colors' => array(
					'id' 			=> 'footer_colors',
					'title' 		=> esc_html__( 'Footer Color Options', 'adventurous-pro' ),
					'description' 	=> '',
				),
			),
		),
		'webmaster_tool' => array(
			'id' 			=> 'webmaster_tool',
			'title' 		=> esc_html__( 'Webmaster Tools', 'adventurous-pro' ),
			'description' 	=> '',
			'sections' 		=> array(
				'predefined_social_icons' => array(
					'id' 			=> 'site_verification',
					'title' 		=> esc_html__( 'Site Verification', 'adventurous-pro' ),
					'description' 	=> '',
				),
				'custom_social_icons' => array(
					'id' 			=> 'header_footer_codes',
					'title' 		=> esc_html__( 'Header Footer Codes', 'adventurous-pro' ),
					'description' 	=> '',
				),
			),
		),
	);

	//Add Panels and sections
	foreach ( $settings_page_tabs as $panel ) {
		$panel_priority = 200;

		if ( 'colors' === $panel['id'] ) {
			$panel_priority = 30;
		}

		$wp_customize->add_panel(
			$theme_slug . $panel['id'],
			array(
				'priority' 		=> $panel_priority,
				'capability' 	=> 'edit_theme_options',
				'title' 		=> $panel['title'],
				'description' 	=> $panel['description'],
			)
		);

		// Loop through tabs for sections
		foreach ( $panel['sections'] as $section ) {
			$params = array(
								'title'			=> $section['title'],
								'description'	=> $section['description'],
								'panel'			=> $theme_slug . $panel['id']
							);

			if ( isset( $section['active_callback'] ) ) {
				$params['active_callback'] = $section['active_callback'];
			}

			$wp_customize->add_section(
				// $id
				$theme_slug . $section['id'],
				// parameters
				$params

			);
		}
	}

	//Create menu option section
	$menu_option_id = $theme_slug . 'menu_option';
	$wp_customize->add_section(
		$menu_option_id,
		array(
			'title' 	=> 'Menu Options',
			'priority' 	=> '100'
		)
	);

	if ( function_exists ( 'has_custom_logo' ) ) {
		$wp_customize->get_control( 'custom_logo' )->priority 		= '1';
	}

	$wp_customize->get_control( 'blogname' )->priority 				= '5';
	$wp_customize->get_control( 'blogdescription' )->priority 		= '11' ;
	$wp_customize->get_control( 'display_header_text' )->priority 	= '13' ;
	$wp_customize->get_control( 'site_icon' )->priority 			= '14' ;


	//Move default header color and background color under custom section basic_colors
	$wp_customize->get_control( 'header_textcolor' )->section = $theme_slug . 'basic_colors' ;
	$wp_customize->get_control( 'header_textcolor' )->priority = 20 ;

	$wp_customize->get_control( 'background_color' )->section = $theme_slug . 'basic_colors' ;
	$wp_customize->get_control( 'background_color' )->priority = 25 ;

	//remove default colors section
	$wp_customize->remove_section('colors');

	$settings_parameters = array(
		//Responsive Design
		'disable_responsive' => array(
			'id' 			=> 'disable_responsive',
			'title' 		=> esc_html__( 'Check to Disable Responsive Design', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'disable_responsive',
			'default' 		=> $defaults['disable_responsive'],
		),
		//Header Featured image Options
		'enable_featured_header_image' => array(
			'id' 			=> 'enable_featured_header_image',
			'title' 		=> esc_html__( 'Enable Featured Header Image', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'section' 		=> 'header_image',
			'default' 		=> $defaults['enable_featured_header_image'],
			'choices'		=> adventurous_enable_header_featured_image(),
		),
		'page_featured_image' => array(
			'id' 			=> 'page_featured_image',
			'title' 		=> esc_html__( 'Page/Post Featured Image Size', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'section' 		=> 'header_image',
			'default' 		=> $defaults['page_featured_image'],
			'choices'		=> adventurous_page_post_featured_image_size(),
			'priority' 		=> '15'
		),
		'featured_header_image_position' => array(
			'id' 			=> 'featured_header_image_position',
			'title' 		=> esc_html__( 'Content Featured Image Position', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_image',
			'default' 		=> $defaults['featured_header_image_position'],
			'choices'		=> adventurous_featured_image_position(),
			'priority' 		=> '16'
		),
		'featured_header_image_alt' => array(
			'id' 			=> 'featured_header_image_alt',
			'title' 		=> esc_html__( 'Featured Header Image Alt/Title Tag', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'section' 		=> 'header_image',
			'default' 		=> $defaults['featured_header_image_alt'],
			'priority' 		=> '17'
		),
		'featured_header_image_url' => array(
			'id' 			=> 'featured_header_image_url',
			'title' 		=> esc_html__( 'Featured Header Image Link URL', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'header_image',
			'default' 		=> $defaults['featured_header_image_url'],
			'priority' 		=> '18'
		),
		'featured_header_image_base' => array(
			'id' 			=> 'featured_header_image_base',
			'title' 		=> esc_html__( 'Check to Open Link in New Tab/Window', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'section' 		=> 'header_image',
			'default' 		=> $defaults['featured_header_image_base'],
			'priority' 		=> '19'
		),
		'reset_featured_image' => array(
			'id' 			=> 'reset_featured_image',
			'title' 		=> esc_html__( 'Check to Reset Header Featured Image Options', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'section' 		=> 'header_image',
			'default' 		=> $defaults['reset_featured_image'],
			'priority' 		=> '20'
		),

		//Menu Options
		'remove_header_menu' => array(
			'id' 			=> 'remove_header_menu',
			'title' 		=> esc_html__( 'Check to Disable Primary Menu', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'menu_option',
			'default' 		=> $defaults['remove_header_menu']
		),

		//Site Identity
		'remove_site_title' => array(
			'id' 			=> 'remove_site_title',
			'title' 		=> esc_html__( 'Check to Disable Site Title', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'section' 		=> 'title_tagline',
			'default' 		=> $defaults['remove_site_title'],
			'priority'		=> '6'
		),
		'remove_site_description' => array(
			'id' 			=> 'remove_site_description',
			'title' 		=> esc_html__( 'Check to Disable Site Description (Tagline)', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'section' 		=> 'title_tagline',
			'default' 		=> $defaults['remove_site_description'],
			'priority'		=> '12'
		),
		'site_title_above' => array(
			'id' 			=> 'site_title_above',
			'title' 		=> esc_html__( 'Check to Move Site Title & Description before Logo', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'section' 		=> 'title_tagline',
			'default' 		=> $defaults['site_title_above'],
			'priority'		=> '17'
		),
		'disable_header_right_search' => array(
			'id' 			=> 'disable_header_right_search',
			'title' 		=> esc_html__( 'Check to Disable Search at Header Right Section', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'section' 		=> 'title_tagline',
			'default' 		=> $defaults['disable_header_right_search'],
			'priority'		=> '20'
		),
		'disable_header_right_sidebar' => array(
			'id' 			=> 'disable_header_right_sidebar',
			'title' 		=> esc_html__( 'Check to Disable Header Right Sidebar', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'section' 		=> 'title_tagline',
			'default' 		=> $defaults['disable_header_right_sidebar'],
			'priority'		=> '25'
		),


		//Promotion Headline Options
		'enable_promotion' => array(
			'id' 			=> 'enable_promotion',
			'title' 		=> esc_html__( 'Enable Promotion Headline on', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'promotion_headline_options',
			'default' 		=> $defaults['enable_promotion'],
			'choices'		=> adventurous_enable_featured_content_options(),
		),
		'promotion_position' => array(
			'id' 				=> 'promotion_position',
			'title' 			=> esc_html__( 'Promotion Headline Postion', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'adventurous_sanitize_select',
			'panel' 			=> 'theme_options',
			'section' 			=> 'promotion_headline_options',
			'default' 			=> $defaults['promotion_position'],
			'choices'			=> adventurous_promotion_headline_postion(),
			'active_callback'	=> 'adventurous_is_promotion_headline_enabled',
		),
		'homepage_headline' => array(
			'id' 				=> 'homepage_headline',
			'title' 			=> esc_html__( 'Homepage Headline Text', 'adventurous-pro' ),
			'description' 		=> esc_html__( 'Appropriate Words: 10', 'adventurous-pro' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_post',
			'panel' 			=> 'theme_options',
			'section' 			=> 'promotion_headline_options',
			'default' 			=> $defaults['homepage_headline'],
			'active_callback'	=> 'adventurous_is_promotion_headline_enabled',
		),
		'homepage_subheadline' => array(
			'id' 				=> 'homepage_subheadline',
			'title' 			=> esc_html__( 'Homepage Subheadline Text', 'adventurous-pro' ),
			'description' 		=> esc_html__( 'Appropriate Words: 15', 'adventurous-pro' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_post',
			'panel' 			=> 'theme_options',
			'section' 			=> 'promotion_headline_options',
			'default' 			=> $defaults['homepage_subheadline'],
			'active_callback'	=> 'adventurous_is_promotion_headline_enabled',
		),
		'homepage_headline_button' => array(
			'id' 				=> 'homepage_headline_button',
			'title' 			=> esc_html__( 'Homepage Headline Button Text ', 'adventurous-pro' ),
			'description'		=> esc_html__( 'Appropriate Words: 3', 'adventurous-pro' ),
			'field_type' 		=> 'text',
			'sanitize' 			=> 'sanitize_text_field',
			'panel' 			=> 'theme_options',
			'section' 			=> 'promotion_headline_options',
			'default' 			=> $defaults['homepage_headline_button'],
			'active_callback'	=> 'adventurous_is_promotion_headline_enabled',
		),
		'homepage_headline_url' => array(
			'id' 				=> 'homepage_headline_url',
			'title' 			=> esc_html__( 'Homepage Headline Link', 'adventurous-pro' ),
			'description'		=> esc_html__( 'Add link for your homepage headline button', 'adventurous-pro' ),
			'field_type' 		=> 'url',
			'sanitize' 			=> 'esc_url_raw',
			'panel' 			=> 'theme_options',
			'section' 			=> 'promotion_headline_options',
			'default' 			=> $defaults['homepage_headline_url'],
			'active_callback'	=> 'adventurous_is_promotion_headline_enabled',
		),
		'homepage_headline_target' => array(
			'id' 				=> 'homepage_headline_target',
			'title' 			=> esc_html__( 'Check to open in new window', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'adventurous_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'promotion_headline_options',
			'default' 			=> $defaults['homepage_headline_target'],
			'active_callback'	=> 'adventurous_is_promotion_headline_enabled',
		),
		'disable_homepage_headline' => array(
			'id' 				=> 'disable_homepage_headline',
			'title' 			=> esc_html__( 'Check to Disable Homepage Headline', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'adventurous_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'promotion_headline_options',
			'default' 			=> $defaults['disable_homepage_headline'],
			'active_callback'	=> 'adventurous_is_promotion_headline_enabled',
		),
		'disable_homepage_subheadline' => array(
			'id' 				=> 'disable_homepage_subheadline',
			'title' 			=> esc_html__( 'Check to Disable Homepage Subheadline', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'adventurous_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'promotion_headline_options',
			'default' 			=> $defaults['disable_homepage_subheadline'],
			'active_callback'	=> 'adventurous_is_promotion_headline_enabled',
		),
		'disable_homepage_button' => array(
			'id' 				=> 'disable_homepage_button',
			'title' 			=> esc_html__( 'Check to Disable Homepage Button', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'adventurous_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'promotion_headline_options',
			'default' 			=> $defaults['disable_homepage_button'],
			'active_callback'	=> 'adventurous_is_promotion_headline_enabled',
		),

		//Homepage/Frontpage Settings
		'enable_posts_home' => array(
			'id' 			=> 'enable_posts_home',
			'title' 		=> esc_html__( 'Check to Disable Latest Posts', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'homepage_settings',
			'default' 		=> $defaults['enable_posts_home']
		),
		'front_page_category' => array(
			'id' 			=> 'front_page_category',
			'title' 		=> esc_html__( 'Homepage posts categories:', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'adventurous-pro' ),
			'field_type' 	=> 'category-multiple',
			'sanitize' 		=> 'adventurous_sanitize_category_list',
			'panel' 		=> 'theme_options',
			'section' 		=> 'homepage_settings',
			'default' 		=> $defaults['front_page_category']
		),

		//Content Featured Image Options
		'featured_image' => array(
			'id' 			=> 'featured_image',
			'title' 		=> esc_html__( 'Content Featured Image Size', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'content_featured_image_options',
			'default' 		=> $defaults['featured_image'],
			'choices'		=> adventurous_content_featured_image_size(),
		),

		//Layout Options
		'sidebar_layout' => array(
			'id' 			=> 'sidebar_layout',
			'title' 		=> esc_html__( 'Sidebar Layout Options', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'layout_options',
			'default' 		=> $defaults['sidebar_layout'],
			'choices'		=> adventurous_sidebar_layout_options(),
		),
		'content_layout' => array(
			'id' 			=> 'content_layout',
			'title' 		=> esc_html__( 'Full Content Display', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'layout_options',
			'default' 		=> $defaults['content_layout'],
			'choices'		=> adventurous_content_layout_options(),
		),
		'reset_layout' => array(
			'id' 			=> 'reset_layout',
			'title' 		=> esc_html__( 'Check to Reset Layout', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'layout_options',
			'default' 		=> $defaults['reset_layout']
		),

		//Font Settings
		'body_font' => array(
			'id' 			=> 'body_font',
			'title' 		=> esc_html__( 'Default Font Family', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_options',
			'default' 		=> $defaults['body_font'],
			'choices'		=> adventurous_available_fonts(),
		),
		'title_font' => array(
			'id' 			=> 'title_font',
			'title' 		=> esc_html__( 'Site Title Font Family', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_options',
			'default' 		=> $defaults['body_font'],
			'choices'		=> adventurous_available_fonts(),
		),
		'tagline_font' => array(
			'id' 			=> 'tagline_font',
			'title' 		=> esc_html__( 'Site Tagline Font Family', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_options',
			'default' 		=> $defaults['body_font'],
			'choices'		=> adventurous_available_fonts(),
		),
		'content_tittle_font' => array(
			'id' 			=> 'content_tittle_font',
			'title' 		=> esc_html__( 'Content Title Font Family', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_options',
			'default' 		=> $defaults['content_tittle_font'],
			'choices'		=> adventurous_available_fonts(),
		),
		'content_font' => array(
			'id' 			=> 'content_font',
			'title' 		=> esc_html__( 'Content Body Font Family', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_options',
			'default' 		=> $defaults['content_font'],
			'choices'		=> adventurous_available_fonts(),
		),
		'headings_font' => array(
			'id' 			=> 'headings_font',
			'title' 		=> esc_html__( 'Headings Tags from h1 to h6 Font Family', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_options',
			'default' 		=> $defaults['headings_font'],
			'choices'		=> adventurous_available_fonts(),
		),
		'reset_typography' => array(
			'id' 			=> 'reset_typography',
			'title' 		=> esc_html__( 'Check to reset font', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_options',
			'default' 		=> $defaults['reset_typography'],
		),

		//Search Settings
		'search_display_text' => array(
			'id' 			=> 'search_display_text',
			'title' 		=> esc_html__( 'Default Display Text in Search', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'search_text_settings',
			'default' 		=> $defaults['search_display_text']
		),

		//Excerpt More Settings
		'more_tag_text' => array(
			'id' 			=> 'more_tag_text',
			'title' 		=> esc_html__( 'More Tag Text', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_more_tag_settings',
			'default' 		=> $defaults['more_tag_text']
		),
		'excerpt_length' => array(
			'id' 			=> 'excerpt_length',
			'title' 		=> esc_html__( 'Excerpt length(words)', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'number',
			'sanitize' 		=> 'adventurous_sanitize_number_range',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_more_tag_settings',
			'default' 		=> $defaults['excerpt_length'],
			'input_attrs' 	=> array(
					            'style' => 'width: 45px;',
					            'min'   => 0,
					            'max'   => 999999,
					            'step'  => 1,
					        	)
		),
		'reset_moretag' => array(
			'id' 			=> 'reset_moretag',
			'title' 		=> esc_html__( 'Check to Reset Excerpt', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_more_tag_settings',
			'default' 		=> $defaults['reset_moretag']
		),

		//Feed Redirect URL
		'feed_url' => array(
			'id' 			=> 'feed_url',
			'title' 		=> esc_html__( 'Feed Redirect URL', 'adventurous-pro' ),
			'description' 	=> esc_html__( 'Add in the Feedburner URL', 'adventurous-pro' ),
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'theme_options',
			'section' 		=> 'feed_url',
			'default' 		=> $defaults['feed_url']
		),

		//Comment Settings
		'commenting_setting' => array(
			'id' 			=> 'commenting_setting',
			'title' 		=> esc_html__( 'Disable Comment', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'commenting_setting',
			'default' 		=> $defaults['commenting_setting'],
			'choices'		=> adventurous_comment_option()
		),

		//Footer Editor Option
		'footer_code' => array(
			'id' 			=> 'footer_code',
			'title' 		=> esc_html__( 'Footer Editor', 'adventurous-pro' ),
			'description' 	=> esc_html__(  'You can add custom <acronym title="Hypertext Markup Language">HTML</acronym> and/or shortcodes, which will be automatically inserted into your theme.<br />Some shortcodes: [the-year], [site-link], [wp-link] for current year, your site link, wordpress site link respectively.', 'adventurous-pro' ),
			'field_type' 	=> 'textarea',
			'sanitize' 		=> 'adventurous_sanitize_footer_code',
			'panel' 		=> 'theme_options',
			'section' 		=> 'footer_option',
			'default' 		=> $defaults['footer_code'],
		),
		'reset_footer' => array(
			'id' 			=> 'reset_footer',
			'title' 		=> esc_html__( 'Check To Reset Footer', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'footer_option',
			'default' 		=> $defaults['reset_footer'],
		),

		//Scroll Settings
		'disable_scrollup' => array(
			'id' 			=> 'disable_scrollup',
			'title' 		=> esc_html__( 'Check to disable scroll up', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'disable_scrollup',
			'default' 		=> $defaults['disable_scrollup'],
		),

		//Notifier Settings
		'disable_notifier' => array(
			'id' 			=> 'disable_notifier',
			'title' 		=> esc_html__( 'Check to disable update notifier', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'disable_notifier',
			'default' 		=> $defaults['disable_notifier'],
		),

		//Custom Css
		'custom_css' => array(
			'id' 			=> 'custom_css',
			'title' 		=> esc_html__( 'Enter your custom CSS styles', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'textarea',
			'sanitize' 		=> 'adventurous_sanitize_custom_css',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_css',
			'default' 		=> $defaults['custom_css']
		),

		//Color Scheme
		'color_scheme' => array(
			'id' 			=> 'color_scheme',
			'title' 		=> esc_html__( 'Enter your custom CSS styles', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'radio',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'colors',
			'section' 		=> 'basic_colors',
			'default' 		=> $defaults['color_scheme'],
			'choices'		=> adventurous_color_schemes()
		),

		//Menu Text Color
		'menu_color' => array(
			'id' 			=> 'menu_color',
			'title' 		=> esc_html__( 'Menu Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_right_menu_colors',
			'default' 		=> $defaults['menu_color'],
		),

		//Menu Hover & Active Text Color
		'hover_active_text_color' => array(
			'id' 			=> 'hover_active_text_color',
			'title' 		=> esc_html__( 'Menu Hover &  Active Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_right_menu_colors',
			'default' 		=> $defaults['hover_active_text_color'],
		),

		//Sub-Menu Top Border Color
		'sub_menu_border_color' => array(
			'id' 			=> 'sub_menu_border_color',
			'title' 		=> esc_html__( 'Sub-Menu Top Border Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_right_menu_colors',
			'default' 		=> $defaults['sub_menu_border_color'],
		),

		//Sub-Menu Background Color
		'sub_menu_bg_color' => array(
			'id' 			=> 'sub_menu_bg_color',
			'title' 		=> esc_html__( 'Sub-Menu Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_right_menu_colors',
			'default' 		=> $defaults['sub_menu_bg_color'],
		),

		//Sub-Menu Text Color
		'sub_menu_text_color' => array(
			'id' 			=> 'sub_menu_text_color',
			'title' 		=> esc_html__( 'Sub-Menu Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_right_menu_colors',
			'default' 		=> $defaults['sub_menu_text_color'],
		),

		//Sub-Menu Hover Background Color
		'hover_active_color' => array(
			'id' 			=> 'hover_active_color',
			'title' 		=> esc_html__( 'Sub-Menu Hover Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_right_menu_colors',
			'default' 		=> $defaults['hover_active_color'],
		),

		//Sub-Menu Hover Text Color
		'sub_menu_hover_color' => array(
			'id' 			=> 'sub_menu_hover_color',
			'title' 		=> esc_html__( 'Sub-Menu Hover Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_right_menu_colors',
			'default' 		=> $defaults['sub_menu_hover_color'],
		),

		//Secondary Menu Background Color
		'secondary_menu_background' => array(
			'id' 			=> 'secondary_menu_background',
			'title' 		=> esc_html__( 'Menu Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_secondary_menu_colors',
			'default' 		=> $defaults['secondary_menu_background'],
		),

		//Secondary Menu Text Color
		'secondary_menu_color' => array(
			'id' 			=> 'secondary_menu_color',
			'title' 		=> esc_html__( 'Menu Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_secondary_menu_colors',
			'default' 		=> $defaults['secondary_menu_color'],
		),

		//Secondary Menu Hover & Active Background Color
		'secondary_hover_active_color' => array(
			'id' 			=> 'secondary_hover_active_color',
			'title' 		=> esc_html__( 'Menu Hover & Active Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_secondary_menu_colors',
			'default' 		=> $defaults['secondary_hover_active_color'],
		),

		//Secondary Menu Hover & Active Text Color
		'secondary_hover_active_text_color' => array(
			'id' 			=> 'secondary_hover_active_text_color',
			'title' 		=> esc_html__( 'Menu Hover & Active Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_secondary_menu_colors',
			'default' 		=> $defaults['secondary_hover_active_text_color'],
		),

		//Secondary Sub-Menu Background Color
		'secondary_sub_menu_bg_color' => array(
			'id' 			=> 'secondary_sub_menu_bg_color',
			'title' 		=> esc_html__( 'Sub-Menu Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_secondary_menu_colors',
			'default' 		=> $defaults['secondary_sub_menu_bg_color'],
		),

		//Secondary Sub-Menu Text Color
		'secondary_sub_menu_text_color' => array(
			'id' 			=> 'secondary_sub_menu_text_color',
			'title' 		=> esc_html__( 'Sub-Menu Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_secondary_menu_colors',
			'default' 		=> $defaults['secondary_sub_menu_text_color'],
		),

		//Secondary Sum-Menu Hover Background Color
		'secondary_sub_menu_hoverbg_color' => array(
			'id' 			=> 'secondary_sub_menu_hoverbg_color',
			'title' 		=> esc_html__( 'Sub-Menu Hover Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_secondary_menu_colors',
			'default' 		=> $defaults['secondary_sub_menu_hoverbg_color'],
		),

		//Secondary Sub-Menu Hover Text Color
		'secondary_sub_menu_hovertext_color' => array(
			'id' 			=> 'secondary_sub_menu_hovertext_color',
			'title' 		=> esc_html__( 'Sub-Menu Hover Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'header_secondary_menu_colors',
			'default' 		=> $defaults['secondary_sub_menu_hovertext_color'],
		),

		//Footer Menu Background Color
		'footer_menu_background' => array(
			'id' 			=> 'footer_menu_background',
			'title' 		=> esc_html__( 'Menu Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_menu_colors',
			'default' 		=> $defaults['footer_menu_background'],
		),

		//Footer Menu Text Color
		'footer_menu_color' => array(
			'id' 			=> 'footer_menu_color',
			'title' 		=> esc_html__( 'Menu Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_menu_colors',
			'default' 		=> $defaults['footer_menu_color'],
		),

		//Footer Menu Hover & Active Background Color
		'footer_hover_active_color' => array(
			'id' 			=> 'footer_hover_active_color',
			'title' 		=> esc_html__( 'Menu Hover & Active Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_menu_colors',
			'default' 		=> $defaults['footer_hover_active_color'],
		),

		//Footer Menu Hover & Active Text Color
		'footer_hover_active_text_color' => array(
			'id' 			=> 'footer_hover_active_text_color',
			'title' 		=> esc_html__( 'Menu Hover & Active Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_menu_colors',
			'default' 		=> $defaults['footer_hover_active_text_color'],
		),

		//Footer Sub-Menu Background Color
		'footer_sub_menu_bg_color' => array(
			'id' 			=> 'footer_sub_menu_bg_color',
			'title' 		=> esc_html__( 'Sub-Menu Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_menu_colors',
			'default' 		=> $defaults['footer_sub_menu_bg_color'],
		),

		//Footer Sub-Menu Text Color
		'footer_sub_menu_text_color' => array(
			'id' 			=> 'footer_sub_menu_text_color',
			'title' 		=> esc_html__( 'Sub-Menu Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_menu_colors',
			'default' 		=> $defaults['footer_sub_menu_text_color'],
		),

		//Footer Sub-Menu Hover Background Color
		'footer_sub_menu_hoverbg_color' => array(
			'id' 			=> 'footer_sub_menu_hoverbg_color',
			'title' 		=> esc_html__( 'Sub-Menu Hover Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_menu_colors',
			'default' 		=> $defaults['footer_sub_menu_hoverbg_color'],
		),

		//Footer Sub-Menu Text Color
		'footer_sub_menu_hovertext_color' => array(
			'id' 			=> 'footer_sub_menu_hovertext_color',
			'title' 		=> esc_html__( 'Sub-Menu Hover Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_menu_colors',
			'default' 		=> $defaults['footer_sub_menu_hovertext_color'],
		),

		//Mobile Hamburger Color
		'mobile_menu_hamburger' => array(
			'id' 			=> 'mobile_menu_hamburger',
			'title' 		=> esc_html__( 'Menu Hamburger Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'mobile_menu_colors',
			'default' 		=> $defaults['mobile_menu_hamburger'],
		),

		//Mobile Hamburger Hover Color
		'mobile_menu_hamburger_hover' => array(
			'id' 			=> 'mobile_menu_hamburger_hover',
			'title' 		=> esc_html__( 'Menu Hamburger Hover Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'mobile_menu_colors',
			'default' 		=> $defaults['mobile_menu_hamburger_hover'],
		),

		//Mobile Menu Background Color
		'mobile_menu_bg_color' => array(
			'id' 			=> 'mobile_menu_bg_color',
			'title' 		=> esc_html__( 'Menu Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'mobile_menu_colors',
			'default' 		=> $defaults['mobile_menu_bg_color'],
		),

		//Mobile Menu Text Color
		'mobile_menu_text_color' => array(
			'id' 			=> 'mobile_menu_text_color',
			'title' 		=> esc_html__( 'Menu Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'mobile_menu_colors',
			'default' 		=> $defaults['mobile_menu_text_color'],
		),

		//Mobile Menu Border Top
		'mobile_menu_border_top' => array(
			'id' 			=> 'mobile_menu_border_top',
			'title' 		=> esc_html__( 'Menu Border Top Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'mobile_menu_colors',
			'default' 		=> $defaults['mobile_menu_border_top'],
		),

		//Mobile Menu Border Color
		'mobile_menu_border' => array(
			'id' 			=> 'mobile_menu_border',
			'title' 		=> esc_html__( 'Menu Border Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'mobile_menu_colors',
			'default' 		=> $defaults['mobile_menu_border'],
		),

		//Mobile Menu Hover Background Color
		'mobile_menu_bg_hover_color' => array(
			'id' 			=> 'mobile_menu_bg_hover_color',
			'title' 		=> esc_html__( 'Menu Hover Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'mobile_menu_colors',
			'default' 		=> $defaults['mobile_menu_hover_bg_color'],
		),

		//Mobile Menu Hover Text Color
		'mobile_menu_hover_text_color' => array(
			'id' 			=> 'mobile_menu_hover_text_color',
			'title' 		=> esc_html__( 'Menu Hover Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'mobile_menu_colors',
			'default' 		=> $defaults['mobile_menu_hover_text_color'],
		),

		//Reset Menu Color Setting
		'reset_menu_color' => array(
			'id' 			=> 'reset_menu_color',
			'title' 		=> esc_html__( 'Check to reset menu color', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'colors',
			'section' 		=> 'reset_menu_color',
			'default' 		=> $defaults['reset_menu_color'],
		),

		//Site Color
		'header_background' => array(
			'id' 			=> 'header_background',
			'title' 		=> esc_html__( 'Header Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['header_background'],
		),
		'featured_background' => array(
			'id' 			=> 'featured_background',
			'title' 		=> esc_html__( 'Featured Content Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['featured_background'],
		),
		'content_background' => array(
			'id' 			=> 'content_background',
			'title' 		=> esc_html__( 'Content Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['content_background'],
		),
		'title_color' => array(
			'id' 			=> 'title_color',
			'title' 		=> esc_html__( 'Content Title Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['title_color'],
		),
		'title_hover_color' => array(
			'id' 			=> 'title_hover_color',
			'title' 		=> esc_html__( 'Content Title Hover Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['title_hover_color'],
		),
		'text_color' => array(
			'id' 			=> 'text_color',
			'title' 		=> esc_html__( 'Content Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['text_color'],
		),
		'meta_color' => array(
			'id' 			=> 'meta_color',
			'title' 		=> esc_html__( 'Content Meta Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['meta_color'],
		),
		'link_color' => array(
			'id' 			=> 'link_color',
			'title' 		=> esc_html__( 'Content Link Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['link_color'],
		),
		'scrollup_bg_color' => array(
			'id' 			=> 'scrollup_bg_color',
			'title' 		=> esc_html__( 'Scroll Up Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['scrollup_bg_color'],
		),
		'scrollup_text_color' => array(
			'id' 			=> 'scrollup_text_color',
			'title' 		=> esc_html__( 'Scroll Up Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['scrollup_text_color'],
		),
		'reset_color' => array(
			'id' 			=> 'reset_color',
			'title' 		=> esc_html__( 'Check to reset', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'colors',
			'section' 		=> 'site_colors',
			'default' 		=> $defaults['reset_color'],
		),

		//Promotion Options
		'promotion_background' => array(
			'id' 			=> 'promotion_background',
			'title' 		=> esc_html__( 'Promotion Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'promotion_colors',
			'default' 		=> $defaults['promotion_background'],
		),
		'home_headline' => array(
			'id' 			=> 'home_headline',
			'title' 		=> esc_html__( 'Promotion Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'promotion_colors',
			'default' 		=> $defaults['home_headline'],
		),
		'promotion_button_background' => array(
			'id' 			=> 'promotion_button_background',
			'title' 		=> esc_html__( 'Promotion Button Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'promotion_colors',
			'default' 		=> $defaults['promotion_button_background'],
		),
		'promotion_button_border_color' => array(
			'id' 			=> 'promotion_button_border_color',
			'title' 		=> esc_html__( 'Promotion Button Border Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'promotion_colors',
			'default' 		=> $defaults['promotion_button_border_color'],
		),
		'promotion_button_text_color' => array(
			'id' 			=> 'promotion_button_text_color',
			'title' 		=> esc_html__( 'Promotion Button Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'promotion_colors',
			'default' 		=> $defaults['promotion_button_text_color'],
		),
		'reset_promotion_color' => array(
			'id' 			=> 'reset_promotion_color',
			'title' 		=> esc_html__( 'Check to reset', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'colors',
			'section' 		=> 'promotion_colors',
			'default' 		=> $defaults['reset_promotion_color'],
		),

		//Sidebar Option
		'sidebar_background' => array(
			'id' 			=> 'sidebar_background',
			'title' 		=> esc_html__( 'Sidebar Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'sidebar_colors',
			'default' 		=> $defaults['sidebar_background'],
		),
		'widget_title_color' => array(
			'id' 			=> 'widget_title_color',
			'title' 		=> esc_html__( 'Sidebar Widget Title Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'sidebar_colors',
			'default' 		=> $defaults['widget_title_color'],
		),
		'widget_color' => array(
			'id' 			=> 'widget_color',
			'title' 		=> esc_html__( 'Sidebar Widget Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'sidebar_colors',
			'default' 		=> $defaults['widget_color'],
		),
		'widget_link_color' => array(
			'id' 			=> 'widget_link_color',
			'title' 		=> esc_html__( 'Sidebar Widget Link Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'sidebar_colors',
			'default' 		=> $defaults['widget_link_color'],
		),
		'reset_sidebar_color' => array(
			'id' 			=> 'reset_sidebar_color',
			'title' 		=> esc_html__( 'Check to reset', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'colors',
			'section' 		=> 'sidebar_colors',
			'default' 		=> $defaults['reset_sidebar_color'],
		),

		//Footer Option
		'footer_sidebar_background' => array(
			'id' 			=> 'footer_sidebar_background',
			'title' 		=> esc_html__( 'Footer Sidebar Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_colors',
			'default' 		=> $defaults['footer_sidebar_background'],
		),
		'footer_widget_title_color' => array(
			'id' 			=> 'footer_widget_title_color',
			'title' 		=> esc_html__( 'Footer Sidebar Widget Title Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_colors',
			'default' 		=> $defaults['footer_widget_title_color'],
		),
		'footer_widget_color' => array(
			'id' 			=> 'footer_widget_color',
			'title' 		=> esc_html__( 'Footer Sidebar Widget Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_colors',
			'default' 		=> $defaults['footer_widget_color'],
		),
		'footer_widget_link_color' => array(
			'id' 			=> 'footer_widget_link_color',
			'title' 		=> esc_html__( 'Footer Sidebar Widget Link Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_colors',
			'default' 		=> $defaults['footer_widget_link_color'],
		),
		'footer_background' => array(
			'id' 			=> 'footer_background',
			'title' 		=> esc_html__( 'Footer Background Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_colors',
			'default' 		=> $defaults['footer_background'],
		),
		'footer_text_color' => array(
			'id' 			=> 'footer_text_color',
			'title' 		=> esc_html__( 'Footer Text Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_colors',
			'default' 		=> $defaults['footer_text_color'],
		),
		'footer_link_color' => array(
			'id' 			=> 'footer_link_color',
			'title' 		=> esc_html__( 'Footer Link Color', 'adventurous-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_colors',
			'default' 		=> $defaults['footer_link_color'],
		),
		'reset_footer_color' => array(
			'id' 			=> 'reset_footer_color',
			'title' 		=> esc_html__( 'Check to reset', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'adventurous-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'adventurous_sanitize_checkbox',
			'panel' 		=> 'colors',
			'section' 		=> 'footer_colors',
			'default' 		=> $defaults['reset_footer_color'],
		),

		//Featured Content
		'enable-featured' => array(
			'id' 			=> 'enable-featured',
			'title' 		=> esc_html__( 'Enable Featured Content', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'featured_content',
			'section' 		=> 'featured_content_settings',
			'default' 		=> $defaults['enable-featured'],
			'choices'		=> adventurous_enable_featured_content_options(),
		),
		'featured_position' => array(
			'id'              => 'featured_position',
			'title'           => esc_html__( 'Featured Content Postition', 'adventurous-pro' ),
			'description'     => '',
			'field_type'      => 'select',
			'sanitize'        => 'adventurous_sanitize_select',
			'panel'           => 'featured_content',
			'section'         => 'featured_content_settings',
			'default'         => $defaults['featured_position'],
			'active_callback' => 'adventurous_is_featured_content_active',
			'choices'         => adventurous_featured_content_position(),
		),
		'homepage_featured_headline' => array(
			'id'              => 'homepage_featured_headline',
			'title'           => esc_html__( 'Featured Content Headline Text', 'adventurous-pro' ),
			'description'     => esc_html__( 'Leave empty if you want to remove headline', 'adventurous-pro' ),
			'field_type'      => 'textarea',
			'sanitize'        => 'sanitize_text_field',
			'panel'           => 'featured_content',
			'section'         => 'featured_content_settings',
			'default'         => $defaults['homepage_featured_headline'],
			'active_callback' => 'adventurous_is_featured_content_active'
		),
		'homepage_featured_subheadline' => array(
			'id'              => 'homepage_featured_subheadline',
			'title'           => esc_html__( 'Featured Content Subheadline Text ', 'adventurous-pro' ),
			'description'     => esc_html__( 'Leave empty if you want to remove Subheadline', 'adventurous-pro' ),
			'field_type'      => 'textarea',
			'sanitize'        => 'sanitize_text_field',
			'panel'           => 'featured_content',
			'section'         => 'featured_content_settings',
			'default'         => $defaults['homepage_featured_subheadline'],
			'active_callback' => 'adventurous_is_featured_content_active'
		),

		'homepage_featured_qty' => array(
			'id'              => 'homepage_featured_qty',
			'title'           => esc_html__( 'Number of Featured Content', 'adventurous-pro' ),
			'description'     => esc_html__( 'Save and refresh the page if No. of Featured Content is changed (Max no of Featured Content is 20)', 'adventurous-pro' ),
			'field_type'      => 'number',
			'sanitize'        => 'adventurous_sanitize_number_range',
			'panel'           => 'featured_content',
			'section'         => 'featured_content_settings',
			'default'         => $defaults['homepage_featured_qty'],
			'active_callback' => 'adventurous_is_featured_content_active',
			'input_attrs'     => array(
					            'style' => 'width: 45px;',
					            'min'   => 0,
					            'max'   => 20,
					            'step'  => 1,
					        	)
		),
		'homepage_featured_layout' => array(
			'id'              => 'homepage_featured_layout',
			'title'           => esc_html__( 'Featured Content Layout', 'adventurous-pro' ),
			'description'     => '',
			'field_type'      => 'radio',
			'sanitize'        => 'adventurous_sanitize_select',
			'panel'           => 'featured_content',
			'section'         => 'featured_content_settings',
			'default'         => $defaults['homepage_featured_layout'],
			'active_callback' => 'adventurous_is_featured_content_active',
			'choices'         => adventurous_featured_content_layouts(),
		),

		//Slider Options
		'enable_slider' => array(
			'id' 			=> 'enable_slider',
			'title' 		=> esc_html__( 'Enable Slider', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'adventurous_sanitize_select',
			'panel' 		=> 'featured_slider',
			'section' 		=> 'slider_options',
			'default' 		=> $defaults['enable_slider'],
			'choices'		=> adventurous_enable_slider_options(),
		),
		'transition_effect' => array(
			'id' 				=> 'transition_effect',
			'title' 			=> esc_html__( 'Transition Effect', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'adventurous_sanitize_select',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['transition_effect'],
			'active_callback'	=> 'adventurous_is_slider_active',
			'choices'			=> adventurous_transition_effects(),
		),
		'transition_delay' => array(
			'id' 				=> 'transition_delay',
			'title' 			=> esc_html__( 'Transition Delay', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'number',
			'sanitize' 			=> 'adventurous_sanitize_number_range',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['transition_delay'],
			'active_callback'	=> 'adventurous_is_slider_active',
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 999999999,
						            'step'  => 1,
						        	)
		),
		'transition_duration' => array(
			'id' 				=> 'transition_duration',
			'title' 			=> esc_html__( 'Transition Length', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'number',
			'sanitize' 			=> 'adventurous_sanitize_number_range',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['transition_duration'],
			'active_callback'	=> 'adventurous_is_slider_active',
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 999999999,
						            'step'  => 1,
						        	)
		),
		'select_slider_type' => array(
			'id' 				=> 'select_slider_type',
			'title' 			=> esc_html__( 'Select Slider Type', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'adventurous_sanitize_select',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['select_slider_type'],
			'active_callback'	=> 'adventurous_is_slider_active',
			'choices'			=> adventurous_slider_types(),
		),
		'slider_qty' => array(
			'id' 				=> 'slider_qty',
			'title' 			=> esc_html__( 'Number of Slides', 'adventurous-pro' ),
			'description'		=> esc_html__( 'Customizer page needs to be refreshed after saving if number of slides is changed', 'adventurous-pro' ),
			'field_type' 		=> 'number',
			'sanitize' 			=> 'adventurous_sanitize_number_range',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['slider_qty'],
			'active_callback'	=> 'adventurous_is_demo_slider_inactive',
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 20,
						            'step'  => 1,
						        	)
		),
		'disable_slider_text' => array(
			'id' 				=> 'disable_slider_text',
			'title' 			=> esc_html__( 'Check to disable slider text', 'adventurous-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'adventurous_sanitize_checkbox',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['disable_slider_text'],
			'active_callback'	=> 'adventurous_is_slider_active',
		),

		//Featured Post Slider
		'exclude_slider_post' => array(
			'id' 				=> 'exclude_slider_post',
			'title' 			=> esc_html__( 'Check to Exclude Slider posts from Homepage posts', 'adventurous-pro' ),
			'description'		=> '',
			'transport'			=> 'postMessage',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'adventurous_sanitize_checkbox',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['exclude_slider_post'],
			'active_callback' 	=> 'adventurous_is_post_slider_active'
		),

		//Featured Category Slider
		'slider_category' => array(
			'id' 				=> 'slider_category',
			'title' 			=> esc_html__( 'Select Slider Categories', 'adventurous-pro' ),
			'description'		=> esc_html__( 'Use this only is you want to display posts from Specific Categories in Featured Slider', 'adventurous-pro' ),
			'field_type' 		=> 'category-multiple',
			'sanitize' 			=> 'adventurous_sanitize_category_list',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['slider_category'],
			'active_callback' 	=> 'adventurous_is_category_slider_active'
		),

		//Social Links
		'social_facebook' => array(
			'id' 			=> 'social_facebook',
			'title' 		=> esc_html__( 'Facebook', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_facebook']
		),
		'social_twitter' => array(
			'id' 			=> 'social_twitter',
			'title' 		=> esc_html__( 'Twitter', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_twitter']
		),
		'social_googleplus' => array(
			'id' 			=> 'social_googleplus',
			'title' 		=> esc_html__( 'Google+', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_googleplus']
		),
		'social_pinterest' => array(
			'id' 			=> 'social_pinterest',
			'title' 		=> esc_html__( 'Pinterest', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_pinterest']
		),
		'social_youtube' => array(
			'id' 			=> 'social_youtube',
			'title' 		=> esc_html__( 'Youtube', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_youtube']
		),
		'social_vimeo' => array(
			'id' 			=> 'social_vimeo',
			'title' 		=> esc_html__( 'Vimeo', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_vimeo']
		),
		'social_linkedin' => array(
			'id' 			=> 'social_linkedin',
			'title' 		=> esc_html__( 'LinkedIn', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_linkedin']
		),
		'social_slideshare' => array(
			'id' 			=> 'social_slideshare',
			'title' 		=> esc_html__( 'Slideshare', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_slideshare']
		),
		'social_foursquare' => array(
			'id' 			=> 'social_foursquare',
			'title' 		=> esc_html__( 'Foursquare', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_foursquare']
		),
		'social_flickr' => array(
			'id' 			=> 'social_flickr',
			'title' 		=> esc_html__( 'Flickr', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_flickr']
		),
		'social_tumblr' => array(
			'id' 			=> 'social_tumblr',
			'title' 		=> esc_html__( 'Tumblr', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_tumblr']
		),
		'social_deviantart' => array(
			'id' 			=> 'social_deviantart',
			'title' 		=> esc_html__( 'deviantART', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_deviantart']
		),
		'social_dribbble' => array(
			'id' 			=> 'social_dribbble',
			'title' 		=> esc_html__( 'Dribbble', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_dribbble']
		),
		'social_myspace' => array(
			'id' 			=> 'social_myspace',
			'title' 		=> esc_html__( 'MySpace', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_myspace']
		),
		'social_wordpress' => array(
			'id' 			=> 'social_wordpress',
			'title' 		=> esc_html__( 'WordPress', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_wordpress']
		),
		'social_rss' => array(
			'id' 			=> 'social_rss',
			'title' 		=> esc_html__( 'RSS', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_rss']
		),
		'social_delicious' => array(
			'id' 			=> 'social_delicious',
			'title' 		=> esc_html__( 'Delicious', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_delicious']
		),
		'social_lastfm' => array(
			'id' 			=> 'social_lastfm',
			'title' 		=> esc_html__( 'Last.fm', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_lastfm']
		),
		'social_instagram' => array(
			'id' 			=> 'social_instagram',
			'title' 		=> esc_html__( 'Instagram', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_instagram']
		),
		'social_github' => array(
			'id' 			=> 'social_github',
			'title' 		=> esc_html__( 'GitHub', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_github']
		),
		'social_vkontakte' => array(
			'id' 			=> 'social_vkontakte',
			'title' 		=> esc_html__( 'Vkontakte', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_vkontakte']
		),
		'social_myworld' => array(
			'id' 			=> 'social_myworld',
			'title' 		=> esc_html__( 'My World', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_myworld']
		),
		'social_odnoklassniki' => array(
			'id' 			=> 'social_odnoklassniki',
			'title' 		=> esc_html__( 'Odnoklassniki', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_odnoklassniki']
		),
		'social_goodreads' => array(
			'id' 			=> 'social_goodreads',
			'title' 		=> esc_html__( 'Goodreads', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_goodreads']
		),
		'social_skype' => array(
			'id' 			=> 'social_skype',
			'title' 		=> esc_html__( 'Skype', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_skype']
		),
		'social_soundcloud' => array(
			'id' 			=> 'social_soundcloud',
			'title' 		=> esc_html__( 'Soundcloud', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_soundcloud']
		),
		'social_email' => array(
			'id' 			=> 'social_email',
			'title' 		=> esc_html__( 'Email', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'sanitize_email',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_email']
		),
		'social_contact' => array(
			'id' 			=> 'social_contact',
			'title' 		=> esc_html__( 'Contact', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_contact']
		),
		'social_xing' => array(
			'id' 			=> 'social_xing',
			'title' 		=> esc_html__( 'Xing', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_xing']
		),
		'social_meetup' => array(
			'id' 			=> 'social_meetup',
			'title' 		=> esc_html__( 'Meetup', 'adventurous-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['social_meetup']
		),
		'custom_social_qty' => array(
			'id' 			=> 'social_custom_qty',
			'title' 		=> esc_html__( 'Number of Custom Social Icons', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Save and refresh the page if No. of custom social icon is changed (Max number of icons is 10)', 'adventurous-pro' ),
			'field_type' 	=> 'number',
			'sanitize' 		=> 'adventurous_sanitize_number_range',
			'panel' 		=> 'social_links',
			'section' 		=> 'custom_social_links',
			'default' 		=> $defaults['social_custom_qty'],
			'input_attrs' 	=> array(
					            'style' => 'width: 45px;',
					            'min'   => 0,
					            'max'   => 10,
					            'step'  => 1,
					        	)
		),

		//Webmaster Setting
		'google_verification' => array(
			'id' 			=> 'google_verification',
			'title' 		=> esc_html__( 'Google Site Verification ID', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Enter your Google ID number only', 'adventurous-pro' ),
			'field_type' 	=> 'text',
			'sanitize' 		=> 'wp_kses_post',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'site_verification',
			'default' 		=> $defaults['google_verification']
		),
		'yahoo_verification' => array(
			'id' 			=> 'yahoo_verification',
			'title' 		=> esc_html__( 'Yahoo Site Verification ID', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Enter your Yahoo ID number only', 'adventurous-pro' ),
			'field_type' 	=> 'text',
			'sanitize' 		=> 'wp_kses_post',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'site_verification',
			'default' 		=> $defaults['yahoo_verification']
		),
		'bing_verification' => array(
			'id' 			=> 'bing_verification',
			'title' 		=> esc_html__( 'Bing Site Verification ID', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Enter your Bing ID number only', 'adventurous-pro' ),
			'field_type' 	=> 'text',
			'sanitize' 		=> 'wp_kses_post',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'site_verification',
			'default' 		=> $defaults['bing_verification']
		),
		'analytic_header' => array(
			'id' 			=> 'analytic_header',
			'title' 		=> esc_html__( 'Code to display on header', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Note: Here you can put scripts from Google, Facebook, Twitter, Add This etc. which will load on Header', 'adventurous-pro' ),
			'field_type' 	=> 'textarea',
			'sanitize' 		=> 'wp_kses_stripslashes',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'header_footer_codes',
			'default' 		=> $defaults['analytic_header']
		),
		'analytic_footer' => array(
			'id' 			=> 'analytic_footer',
			'title' 		=> esc_html__( 'Code to display on footer', 'adventurous-pro' ),
			'description'	=> esc_html__( 'Note: Here you can put scripts from Google, Facebook, Twitter, Add This etc. which will load on footer', 'adventurous-pro' ),
			'field_type' 	=> 'textarea',
			'sanitize' 		=> 'wp_kses_stripslashes',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'header_footer_codes',
			'default' 		=> $defaults['analytic_footer']
		),
	);

	//@remove Remove if block when WordPress 4.8 is released
	if ( !function_exists( 'has_custom_logo' ) ) {
		$settings_logo = array(
			'featured_logo_header' => array(
				'id' 			=> 'featured_logo_header',
				'title' 		=> esc_html__( 'Logo', 'adventurous-pro' ),
				'description'	=> '',
				'field_type' 	=> 'image',
				'sanitize' 		=> 'adventurous_sanitize_image',
				'section' 		=> 'title_tagline',
				'default' 		=> $defaults['featured_logo_header'],
				'priority'		=> '15'
			),
			'remove_header_logo' => array(
				'id' 			=> 'remove_header_logo',
				'title' 		=> esc_html__( 'Check to Disable Logo', 'adventurous-pro' ),
				'description'	=> '',
				'field_type' 	=> 'checkbox',
				'sanitize' 		=> 'adventurous_sanitize_checkbox',
				'section' 		=> 'title_tagline',
				'default' 		=> $defaults['remove_header_logo'],
				'priority'		=> '16'
			)
		);

		$settings_parameters = array_merge( $settings_parameters, $settings_logo);
	}

	//@remove Remove if block and custom_css from $settings_paramater when WordPress 5.0 is released
	if( function_exists( 'wp_update_custom_css_post' ) ) {
		unset( $settings_parameters['custom_css'] );
	}

	foreach ( $settings_parameters as $option ) {
		$priority = isset( $option[ 'priority' ] ) ? $option[ 'priority' ] : '';
		$transport = isset( $option[ 'transport' ] ) ? $option[ 'transport' ] : 'refresh';
		if ( 'color' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					array(
						'label'		=> $option['title'],
						'section'   => $theme_slug . $option['section'],
						'settings'  => $theme_slug . 'options[' . $option['id'] . ']',
						'priority'	=> $priority
					)
				)
			);
		}

		if ( 'image' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport
				)
			);

			if ( 'header_image' == $option['section'] || 'title_tagline' == $option['section'] ) {
				$option['section'] = $option['section'];
			} else {
				$option['section'] = $theme_slug . $option['section'];
			}

			$wp_customize->add_control(
				new WP_Customize_Image_Control(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					array(
						'label'		=> $option['title'],
						'section'   => $option['section'],
						'settings'  => $theme_slug . 'options[' . $option['id'] . ']',
						'priority'	=> $priority
					)
				)
			);
		}
		else if ('checkbox' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'priority'			=> $priority,
					'transport'			=> $transport
				)
			);

			$params = array(
						'label'			=> $option['title'],
						'description'	=> $option['description'],
						'settings'  	=> $theme_slug . 'options[' . $option['id'] . ']',
						'name'  		=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'		=> $priority
					);

			if ( isset( $option['active_callback']  ) ) {
				$params['active_callback'] = $option['active_callback'];
			}

			if ( 'header_image' == $option['section'] || 'title_tagline' == $option['section'] ) {
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}
			$wp_customize->add_control(
				new Adventurous_Customize_Checkbox(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		else if ('category-multiple' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport
				)
			);

			$params = array(
						'label'			=> $option['title'],
						'section'		=> $theme_slug . $option['section'],
						'settings'		=> $theme_slug . 'options[' . $option['id'] . ']',
						'description'	=> $option['description'],
						'name'	 		=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'	=> $priority
					);

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			$wp_customize->add_control(
				new Adventurous_Customize_Dropdown_Categories_Control (
					$wp_customize,
					$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		else {
			//Normal Loop
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'default'			=> $option['default'],
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'transport'			=> $transport
				)
			);

			// Add setting control
			$params = array(
					'label'			=> $option['title'],
					'settings'		=> $theme_slug . 'options[' . $option['id'] . ']',
					'type'			=> $option['field_type'],
					'description'   => $option['description'],
					'priority'		=> $priority
				) ;

			if ( isset( $option['choices']  ) ){
				$params['choices'] = $option['choices'];
			}

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			if ( isset( $option['input_attrs']  ) ){
				$params['input_attrs'] = $option['input_attrs'];
			}

			if ( 'header_image' == $option['section'] || 'title_tagline' == $option['section'] ) {
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}

			$wp_customize->add_control(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				$params
			);
		}
	}

	//Add featured content elements with respect to no of featured content
	for ( $i = 1; $i <= $options['homepage_featured_qty']; $i++ ) {
		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[homepage_featured_content_note][' . $i . ']',
			// parameters array
			array(
					'type'              => 'option',
					'sanitize_callback' => 'sanitize_text_field'
				)
		);

		$wp_customize->add_control(
			new Adventurous_Note_Control(
				$wp_customize, $theme_slug . 'options[homepage_featured_content_note][' . $i . ']',
				array(
					'label'           => sprintf(esc_html__( 'Featured Content #%s', 'adventurous-pro' ), $i ),
					'section'         => $theme_slug .'featured_content_settings',
					'settings'        => $theme_slug . 'options[homepage_featured_content_note][' . $i . ']',
					'active_callback' => 'adventurous_is_featured_content_active'
				)
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[homepage_featured_image][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'adventurous_sanitize_image'
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize, $theme_slug . 'options[homepage_featured_image][' . $i . ']',
				array(
					'label'           => esc_html__( 'Image', 'adventurous-pro' ),
					'section'         => $theme_slug .'featured_content_settings',
					'settings'        => $theme_slug . 'options[homepage_featured_image][' . $i . ']',
					'active_callback' => 'adventurous_is_featured_content_active'
				)
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[homepage_featured_url][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[homepage_featured_url][' . $i . ']',
			array(
				'label'           => esc_html__( 'Link URL', 'adventurous-pro' ),
				'section'         => $theme_slug .'featured_content_settings',
				'settings'        => $theme_slug . 'options[homepage_featured_url][' . $i . ']',
				'type'            => 'url',
				'active_callback' => 'adventurous_is_featured_content_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[homepage_featured_base][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'adventurous_sanitize_checkbox'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[homepage_featured_base][' . $i . ']',
			array(
				'label'           => esc_html__( 'Check to open Link in New Window', 'adventurous-pro' ),
				'section'         => $theme_slug .'featured_content_settings',
				'settings'        => $theme_slug . 'options[homepage_featured_base][' . $i . ']',
				'type'            => 'checkbox',
				'active_callback' => 'adventurous_is_featured_content_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[homepage_featured_title][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[homepage_featured_title][' . $i . ']',
			array(
				'label'           => esc_html__( 'Title', 'adventurous-pro' ),
				'section'         => $theme_slug .'featured_content_settings',
				'settings'        => $theme_slug . 'options[homepage_featured_title][' . $i . ']',
				'description'     => esc_html__( 'Leave empty if you want to remove title', 'adventurous-pro' ),
				'type'            => 'text',
				'active_callback' => 'adventurous_is_featured_content_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[homepage_featured_content][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'wp_kses_post'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[homepage_featured_content][' . $i . ']',
			array(
				'label'           => esc_html__( 'Content', 'adventurous-pro' ),
				'section'         => $theme_slug .'featured_content_settings',
				'settings'        => $theme_slug . 'options[homepage_featured_content][' . $i . ']',
				'description'     => esc_html__( 'Appropriate Words: 10', 'adventurous-pro' ),
				'type'            => 'textarea',
				'active_callback' => 'adventurous_is_featured_content_active'
			)
		);
	}

	//Add featured post elements with respect to no of featured sliders
	for ( $i = 1; $i <= $options['slider_qty']; $i++ ) {
		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_slider][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'adventurous_sanitize_post_id'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_slider][' . $i . ']',
			array(
					'label'           => sprintf(esc_html__( 'Featured Post Slider ID #%s', 'adventurous-pro' ), $i ),
					'section'         => $theme_slug .'slider_options',
					'settings'        => $theme_slug . 'options[featured_slider][' . $i . ']',
					'type'            => 'text',
					'input_attrs'     => array(
						'style' => 'width: 100px;'
					),
					'active_callback' => 'adventurous_is_post_slider_active'
			)
		);
	}

	//Add featured page elements with respect to no of featured slider
	for ( $i = 1; $i <= $options['slider_qty']; $i++ ) {
		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_slider_page][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'adventurous_sanitize_post_id'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_slider_page][' . $i . ']',
			array(
				'label'           => sprintf(esc_html__( 'Featured Page Slider #%s', 'adventurous-pro' ), $i ),
				'section'         => $theme_slug .'slider_options',
				'settings'        => $theme_slug . 'options[featured_slider_page][' . $i . ']',
				'type'            => 'dropdown-pages',
				'active_callback' => 'adventurous_is_page_slider_active'
			)
		);
	}

	//Add featured image elements with respect to no of featured slider
	for ( $i = 1; $i <= $options['slider_qty']; $i++ ) {
		$wp_customize->add_setting( $theme_slug . 'options[featured_slider_note]['. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Adventurous_Note_Control(
			$wp_customize,
			$theme_slug . 'options[featured_slider_note]['. $i .']', array(
			'active_callback' => 'adventurous_is_image_slider_active',
			'label'           => esc_html__( 'Featured Slide #', 'adventurous-pro' ) . $i,
			'section'         => $theme_slug .'slider_options',
			'settings'        => $theme_slug . 'options[featured_slider_note][' . $i . ']',
			'type'            => 'description',
   		) ) );

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_image][' . $i . ']',
			// parameters array
			array(
				'type'              => 'option',
				'sanitize_callback' => 'adventurous_sanitize_image'
			)
		);

		$wp_customize->add_control( new WP_Customize_Image_Control(
				$wp_customize,
				$theme_slug . 'options[featured_image_slider_image][' . $i . ']',
				array(
					'label'           => esc_html__( 'Image', 'adventurous-pro' ),
					'section'         => $theme_slug .'slider_options',
					'settings'        => $theme_slug . 'options[featured_image_slider_image][' . $i . ']',
					'active_callback' => 'adventurous_is_image_slider_active'
				)
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_link][' . $i . ']',
			// parameters array
			array(
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_link][' . $i . ']',
			array(
				'label'           => esc_html__( 'Link', 'adventurous-pro' ),
				'section'         => $theme_slug .'slider_options',
				'settings'        => $theme_slug . 'options[featured_image_slider_link][' . $i . ']',
				'type'            => 'url',
				'active_callback' => 'adventurous_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_base][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'adventurous_sanitize_checkbox'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_base][' . $i . ']',
			array(
				'label'           => esc_html__( 'Check to Open Link in New Window/Tab ', 'adventurous-pro' ),
				'section'         => $theme_slug .'slider_options',
				'settings'        => $theme_slug . 'options[featured_image_slider_base][' . $i . ']',
				'type'            => 'checkbox',
				'active_callback' => 'adventurous_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_title][' . $i . ']',
			// parameters array
			array(
				'type'              => 'option',
				'sanitize_callback' => 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_title][' . $i . ']',
			array(
				'label'           => esc_html__( 'Title', 'adventurous-pro' ),
				'section'         => $theme_slug .'slider_options',
				'settings'        => $theme_slug . 'options[featured_image_slider_title][' . $i . ']',
				'type'            => 'text',
				'active_callback' => 'adventurous_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_content][' . $i . ']',
			// parameters array
			array(
				'type'              => 'option',
				'sanitize_callback' => 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_content][' . $i . ']',
			array(
				'label'           => esc_html__( 'Content', 'adventurous-pro' ),
				'section'         => $theme_slug .'slider_options',
				'settings'        => $theme_slug . 'options[featured_image_slider_content][' . $i . ']',
				'type'            => 'textarea',
				'active_callback' => 'adventurous_is_image_slider_active'
			)
		);
	}

	//Add custom social elements with respect to number of custom social icons
	for ( $i = 1; $i <= $options['social_custom_qty']; $i++ ) {
		$wp_customize->add_setting( $theme_slug . 'options[social_custom_note]['. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Adventurous_Note_Control(
			$wp_customize,
			$theme_slug . 'options[social_custom_note]['. $i .']', array(
			'label'    => esc_html__( 'Custom Social icon #', 'adventurous-pro' ) . $i,
			'section'  => $theme_slug .'custom_social_links',
			'settings' => $theme_slug . 'options[social_custom_note][' . $i . ']',
			'type'     => 'description',
   		) ) );

   		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[social_custom_name][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[social_custom_name][' . $i . ']',
			array(
				'label'    => esc_html__( 'Name', 'adventurous-pro' ),
				'section'  => $theme_slug .'custom_social_links',
				'settings' => $theme_slug . 'options[social_custom_name][' . $i . ']',
				'type'     => 'text',
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[social_custom_image][' . $i . ']',
			// parameters array
			array(
				'type'              => 'option',
				'sanitize_callback' => 'adventurous_sanitize_image'
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				$theme_slug . 'options[social_custom_image][' . $i . ']',
				array(
					'label'    => sprintf(esc_html__( 'Image URL', 'adventurous-pro' ), $i ),
					'section'  => $theme_slug .'custom_social_links',
					'settings' => $theme_slug . 'options[social_custom_image][' . $i . ']',
				)
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[social_custom_image_hover][' . $i . ']',
			// parameters array
			array(
				'type'              => 'option',
				'sanitize_callback' => 'adventurous_sanitize_image'
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				$theme_slug . 'options[social_custom_image_hover][' . $i . ']',
				array(
					'label'    => sprintf(esc_html__( 'Image URL on hover', 'adventurous-pro' ), $i ),
					'section'  => $theme_slug .'custom_social_links',
					'settings' => $theme_slug . 'options[social_custom_image_hover][' . $i . ']',
				)
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[social_custom_url][' . $i . ']',
			// parameters array
			array(
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[social_custom_url][' . $i . ']',
			array(
				'label'    => esc_html__( 'Link', 'adventurous-pro' ),
				'section'  => $theme_slug .'custom_social_links',
				'settings' => $theme_slug . 'options[social_custom_url][' . $i . ']',
				'type'     => 'url',
			)
		);
	}

	// Reset all settings to default
	$wp_customize->add_section( 'adventurous_reset_all_settings', array(
		'description' => esc_html__( 'Caution: Reset all settings to default. Refresh the page after save to view full effects.', 'adventurous-pro' ),
		'priority'    => 700,
		'title'       => esc_html__( 'Reset all settings', 'adventurous-pro' ),
	) );

	$wp_customize->add_setting( 'adventurous_options[reset_all_settings]', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback' => 'adventurous_sanitize_checkbox',
		'transport'			=> 'postMessage',
		'type'              => 'option',
	) );

	$wp_customize->add_control( 'adventurous_options[reset_all_settings]', array(
		'label'    => esc_html__( 'Check to reset all settings to default', 'adventurous-pro' ),
		'section'  => 'adventurous_reset_all_settings',
		'settings' => 'adventurous_options[reset_all_settings]',
		'type'     => 'checkbox'
	) );
	// Reset all settings to default end

	//Important Links
	$wp_customize->add_section( 'important_links', array(
		'priority' => 999,
		'title'    => esc_html__( 'Important Links', 'adventurous-pro' ),
	) );

	/**
	 * Has dummy Sanitizaition function as it contains no value to be sanitized
	 */
	$wp_customize->add_setting( 'important_links', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Adventurous_Important_Links( $wp_customize, 'important_links', array(
        'label'   	=> esc_html__( 'Important Links', 'adventurous-pro' ),
        'section'  	=> 'important_links',
        'settings' 	=> 'important_links',
        'type'     	=> 'important_links',
    ) ) );
    //Important Links End
}
add_action( 'customize_register', 'adventurous_customize_register' );


/*
 * Clearing the cache if any changes in Admin Theme Option
 */
function adventurous_flush_transients() {
	delete_transient('adventurous_responsive'); // Responsive design
	delete_transient( 'adventurous_featured_image' ); // featured header image
	delete_transient( 'adventurous_inline_css' ); // Custom Inline CSS
	delete_transient( 'adventurous_post_sliders' ); // featured post slider
	delete_transient( 'adventurous_page_sliders' ); // featured page slider
	delete_transient( 'adventurous_category_sliders' ); // featured category slider
	delete_transient( 'adventurous_image_sliders' ); // featured image slider
	delete_transient( 'adventurous_default_sliders' ); //Default slider
	delete_transient( 'adventurous_homepage_headline' ); // Homepage Headline Message
	delete_transient( 'adventurous_default_featured_content' ); // Homepage Default Featured Content
	delete_transient( 'adventurous_homepage_featured_content' ); // Homepage Featured Content
	delete_transient( 'adventurous_footer_content' ); // Footer Content
	delete_transient( 'adventurous_social_networks' ); // Social Networks
	delete_transient( 'adventurous_webmaster' ); // scripts which loads on header
	delete_transient( 'adventurous_footercode' ); // scripts which loads on footer
	delete_transient( 'adventurous_scrollup' ); // Scroll up Navigation
}


/*
 * Clearing the cache if any changes in post or page
 */
function adventurous_flush_post_transients(){
	delete_transient( 'adventurous_post_sliders' ); // featured post slider
	delete_transient( 'adventurous_page_sliders' ); // featured page slider
	delete_transient( 'adventurous_category_sliders' ); // featured category slider
}
//Add action hook here save post
add_action( 'save_post', 'adventurous_flush_post_transients' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously for adventurous.
 * And flushes out all transient data on preview
 *
 * @since Adventurous 3.4
 */
function adventurous_customize_preview() {
	//Remove transients on preview
	adventurous_flush_transients();
}
add_action( 'customize_preview_init', 'adventurous_customize_preview' );
add_action( 'customize_save', 'adventurous_customize_preview' );


/**
 * Custom scripts and styles on Customizer for Adventurous
 *
 * @since Adventurous 3.4
 */
function adventurous_customize_scripts() {
	wp_enqueue_script( 'adventurous_customizer_custom', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'inc/panel/js/customizer-custom-scripts.js', array( 'jquery' ), '20140108', true );
}
add_action( 'customize_controls_enqueue_scripts', 'adventurous_customize_scripts' );


/**
 * Function to reset date with respect to condition
 */
function adventurous_reset_data() {
	$options  = adventurous_get_options();
    if ( $options['reset_all_settings'] ) {
    	remove_theme_mods();

    	delete_option( 'adventurous_options' );

        // Flush out all transients	on reset
        adventurous_flush_transients();

        return;
    }

	$defaults = adventurous_get_defaults();

	//Reset Header Featured Image Options
	if ( $options['reset_featured_image'] ) {
		unset( $options['enable_featured_header_image'] );
		unset( $options['page_featured_image'] );
		unset( $options['featured_header_image_position'] );
		unset( $options['featured_header_image_alt'] );
		unset( $options['featured_header_image_url'] );
		unset( $options['featured_header_image_base'] );
		unset( $options['reset_featured_image'] );

        remove_theme_mod( 'header_image' );
	}

	// Reset Site Color Options
	if ( $options['reset_color'] ) {
        unset( $options['color_scheme'] );
        unset( $options['header_background'] );
        unset( $options['featured_background'] );
        unset( $options['content_background'] );
        unset( $options['title_color'] );
        unset( $options['title_hover_color'] );
        unset( $options['meta_color'] );
        unset( $options['text_color'] );
        unset( $options['link_color'] );
        unset( $options['scrollup_bg_color'] );
        unset( $options['scrollup_text_color'] );

		unset( $options['reset_color'] );
	}

    // Reset Promotion Color Options
	if ( $options['reset_promotion_color'] ) {
        unset( $options['promotion_background'] );
        unset( $options['home_headline'] );
        unset( $options['promotion_button_background'] );
        unset( $options['promotion_button_border_color'] );
        unset( $options['promotion_button_text_color'] );

		unset( $options['reset_promotion_color'] );
	}

	// Reset Sidebar Color Options
	if ( $options['reset_sidebar_color'] ) {
        unset( $options['sidebar_background'] );
        unset( $options['widget_title_color'] );
        unset( $options['widget_color'] );
        unset( $options['widget_link_color'] );

		unset( $options['reset_sidebar_color'] );
	}

	// Reset Footer Color Options
	if ( $options['reset_footer_color'] ) {
        unset( $options['footer_sidebar_background'] );
        unset( $options['footer_widget_title_color'] );
        unset( $options['footer_widget_color'] );
        unset( $options['footer_widget_link_color'] );
        unset( $options['footer_background'] );
        unset( $options['footer_text_color'] );
        unset( $options['footer_link_color'] );

		unset( $options['reset_footer_color'] );
	}

	// Reset Menu Colors
	if ( $options['reset_menu_color'] ) {
		unset( $options['menu_color'] );
		unset( $options['hover_active_text_color'] );
		unset( $options['sub_menu_border_color'] );
		unset( $options['sub_menu_bg_color'] );
		unset( $options['sub_menu_text_color'] );
		unset( $options['hover_active_color'] );
		unset( $options['sub_menu_hover_color'] );

		unset( $options['secondary_menu_background'] );
		unset( $options['secondary_menu_color'] );
		unset( $options['secondary_hover_active_color'] );
		unset( $options['secondary_hover_active_text_color'] );
		unset( $options['secondary_sub_menu_bg_color'] );
		unset( $options['secondary_sub_menu_text_color'] );
		unset( $options['secondary_sub_menu_hoverbg_color'] );
		unset( $options['secondary_sub_menu_hovertext_color'] );

		unset( $options['footer_menu_background'] );
		unset( $options['footer_menu_color'] );
		unset( $options['footer_hover_active_color'] );
		unset( $options['footer_hover_active_text_color'] );
		unset( $options['footer_sub_menu_bg_color'] );
		unset( $options['footer_sub_menu_text_color'] );
		unset( $options['footer_sub_menu_hoverbg_color'] );
		unset( $options['footer_sub_menu_hovertext_color'] );

		unset( $options['mobile_menu_hamburger'] );
		unset( $options['mobile_menu_hamburger_hover'] );
		unset( $options['mobile_menu_bg_color'] );
		unset( $options['mobile_menu_text_color'] );
		unset( $options['mobile_menu_border_top'] );
		unset( $options['mobile_menu_border'] );
		unset( $options['mobile_menu_hover_bg_color'] );
		unset( $options['mobile_menu_hover_text_color'] );

		unset( $options['reset_menu_color'] );
	}


	//Reset Typograpny Options
	if ( $options[ 'reset_typography'] ) {
        unset( $options['body_font'] );
        unset( $options['title_font'] );
        unset( $options['tagline_font'] );
        unset( $options['content_tittle_font'] );
        unset( $options['content_font'] );
        unset( $options['headings_font'] );

        unset( $options['reset_typography'] );
	}

	//Reset Color Options
	if ( $options['reset_moretag'] ) {
		unset( $options['more_tag_text'] );
		unset( $options['excerpt_length'] );

		unset( $options['reset_moretag'] );
	}

	//Reset Color Options
	if ( $options['reset_layout'] ) {
		unset( $options['sidebar_layout'] );
		unset( $options['content_layout'] );
		unset( $options['featured_image'] );

        unset( $options['reset_layout'] );
	}

	if ( $options['reset_footer'] ) {
		unset( $options['footer_code'] );

        unset( $options['reset_footer'] );
	}

	update_option( 'adventurous_options', $options );

	// Flush out all transients	on reset
	adventurous_flush_transients();
}
add_action( 'customize_save_after', 'adventurous_reset_data' );


//Active callbacks for customizer
require trailingslashit( get_template_directory() ) . 'inc/panel/customizer/customizer-active-callbacks.php';

//Sanitize functions for customizer
require trailingslashit( get_template_directory() ) . 'inc/panel/customizer/customizer-sanitize-functions.php';
